:mod:`euphorie.client.client`
=============================

.. automodule:: euphorie.client.client

.. autointerface:: IClient

.. autoclass:: Client


Views
-----

.. autoclass:: View


Account support
---------------

.. autoclass:: ClientUserProvider

.. autoclass:: ClientLocalRolesProvider

Traversal logic
---------------

.. autoclass:: ClientPublishTraverser
